/******************************************************************************
 *** Ukrainian i18l Strings                                                   ***
 ******************************************************************************/
msgid(LANG_NATIVE_NAME)
msgstr("Українська")

msgid(LANG_ENGLISH_NAME)
msgstr("UKRAINIAN")


/******************************************************************************
 *** Splash Message & Change Log                                            ***
 ******************************************************************************/
msgid(SPLASH_TITLE)
msgstr("Вас вітає новий uTox!")

msgid(SPLASH_TEXT)
msgstr("Ви щойно оновилися до версії 0.17.0! Ім'я випуску: bork bork")

msgid(CHANGE_LOG_TITLE)
msgstr("Зміни у v0.17.0")

msgid(CHANGE_LOG_TEXT)
msgstr(
"\n  ВАЖЛИВА ІНФОРМАЦІЯ ДЛЯ КОРИСТУВАЧІВ WINDOWS \n"
"    Наразі в оновлювача існує проблема з деякими іменами exe-файлів.\n"
"    Для того, щоб він надійно працював, переіменуйте exe-файл на \"uTox.exe\"\n"
"    та увімкніть його в налаштуваннях.\n"
"\n"
"  Функції:\n"
"   Підтримка Toxcore 0.2.x!\n"
"   Збереження налаштувань у зрозумілому .ini-файлі.\n"
"   Підтримка Tox URI.\n"
"   Випадаючі опції залишаються відкритими після натискання.\n"
"   Можливість згенерувати QR-код вашого ToxID.\n"
"   Підтримка естонської мови.\n"
"  Виправлення:\n"
"    Кольорова схема Zenburn тепер працює.\n"
"    Дзвінки додаються до історії чату.\n"
"    Зберігання вбудованих малюнків працює для не-ASCII імен.\n"
"    GTK має працювати на різних платформах.\n"
"    Експорт історії чату на MacOS не призводить до збоїв.\n"
"    Підтримка передавання файлів на MacOS.n"
"    Налаштування проксі тепер зберігаються.\n"
"    Значок системного лотка, здається, має здебільшого працювати на (майже) всіх Linux-системах.\n"
"    Численні виправлення інтерфейсу.\n"
"    Підтримка сигналів на Linux-системах.\n"
"    Фільтрування аудіо знову можна увімкнути.\n"
"    Значок системного лотка Windows оновлюється у випадку збоїв Explorer'а.\n"
"    Неправильні значення FPS більше не виникають при завантаженні старих налаштувань.\n"
"    Формат дати тепер зберігається.\n"
"    Краща підтримка не-ASCII символів.\n"
"    Підказки тепер залишаютсья в межах вікна.\n"
"  Розробка:\n"
"    Тепер можливо вказати розташування бібліотеки у CMAKE_PREFIX_PATH.\n"
"\nv0.16.0\n"
"  Функції:\n"
"   Мова тепер зберігається.\n"
"   Додано групові аудіорозмови.\n"
"   Можливість зміни частоти кадрів під час дзвінка.\n"
"  Виправлення:\n"
"    Більш стабільна робота в OSX.\n"
"    Відео знову працює у Linux.\n"
"    Виправлення інтерфейсу. (подяки redmanmale!)\n"
"    Виправлено заголовок вікна попереднього перегляду у Windows. (подяки thorpelawrence!)\n"
"    Виправлено деякі збої під час групової бесіди.\n"
"    Кнопки миші в X11 тепер працюють правильно. (подяки dkmoz!)\n"
"    У Windows тепер працюють веб-адреси в юнікоді.\n"
"    Очищення імен файлів у Windows.\n"
"    Налаштування автоприймання файлів тепер зберігаються.\n"
"    Звукові сповіщення тепер звучать тільки коли вікно uTox неактивне.\n"
"    Повідомлення позначаються як прочитані, якщо вони отримані у відкрите вікно чату.\n"
"    Діалог обрання файлів GTK тепер працює в OpenBSD та NetBSD.\n"
"    Виправлено перемикач автозапуску.\n"
"    Виправлено сповіщення про набирання повідомлення.\n"
"    При експорті історії чату вказано час повідомлень.\n"
"  Розробка:\n"
"    Припинено підтримку ToxDNS.\n"
"    Додано інструкції збирання для OSX. (подяки @publicarray!)\n"
"    В OSX тепер також виконуються тести.\n"
"    Додано сценарій на Python, що шукає відсутні переклади.\n"
"    Зменшено розмір збірки MinSizeRel.\n"
"    Оновлено численні переклади.\n"
"\nv0.15.0\n"
"  Функції:\n"
"    Оновлений інтерфейс. (Подяки redmanmale!)\n"
"    Висувна бічна панель на Android.\n"
"  Виправлення:\n"
"    Відео знову працює у Windows.\n"
"    Автоприймання файлів у переносній версії тепер зберігає файли у переносну папку.\n"
"    Оновлено український переклад. (Подяки v2e!)\n"
"    Сповіщення через Dbus тепер мають працювати на різних системах.\n"
"  Розробка\n"
"    Додано підтримку NetBSD, OpenBSD та FreeBSD.\n"
"    Перебудовано інтерфейс.\n"
"\nv0.14.0\n"
"  Функції:\n"
"    Справжній оновлювач.\n"
"       -- uTox тепер має вбудований оновлювач. Наразі тільки для Windows.\n"
"       -- Але його можна адаптувати до будь-якої платформи, якщо є бажання.\n"
"    Додано підтримку musl libc.\n"
"    uTox тепер зібрано з сильнішим захистом від експлойтів.\n"
"    Значно зменшено використання пам'яті для списку друзів.\n"
"  Виправлення:\n"
"    Нові антиспам-коди більше не починаються з 0000.\n"
"    Виправлено вирівнювання кнопок з обранням мови.\n"
"    tox_save більше не обрізається під час виходу.\n"
"    Значок у системному лотку тепер завжди має квадратне тло\n"
"       -- Навіть у несправних екранних менеджерах (uTox дивиться на Gnome...)\n"
"    Оновлено список початкових вузлів.\n"
"    Аватари тепер можна видаляти.\n"
"    Сповіщення більше не ігноруються, коли uTox згорнуто.\n"
"    Декілька виправлень передачі файлів.\n"
"       -- Особливо останнє, яке чомусь уникало оновлень.\n"
"  Розробка\n"
"    Усі попередження виправлено, додано -Werror\n"
"    Додано тести:\n"
"                Оновлювач uTox\n"
"                Читання та запис історії чату\n"
"    Ще трохи перероблено інтерфейс. Що заразом усунуло деякі недоліки інтерфейсу.\n"
"\nv0.13.0\n"
"  Функції:\n"
"    Відтепер можна вставляти текст у кодуванні UTF-8 в uTox.\n"
"    Відтепер можна вручну обрати антиспам-код!\n"
"\n  Виправлення:\n"
"    Здебільшого виправлено груповий чат. (Принаймні він тепер не руйнує uTox раптово...)\n"
"    Знову можна зберігати історію чату у Windows.\n"
"    Очищення історії більше не руйнує uTox.\n"
"    Заткнено багато дірок, крізь які витікала пам'ять.\n"
"    Прокрутка клавішами PgUp/PgDn тепер оновлює усе вікно чату.\n"
"    Аватари знову завантажуються.\n"
"    Власні теми тепер працюють і не руйнують uTox, якщо перемкнутися на тему, яка не існує\n"
"    Численні покращення системи збирання.\n"
"    Багато виправлень передачі файлів.\n"
"\n  Розробка\n"
"    uTox тепер має модульне тестування! (Сподіваємося, в нас більше ніколи не буде багів.)\n"
"    Файли інтерфейсу розділено на ui та layout.\n"
"    В нас тепер є власний сервер компіляції!\n"
"\nv0.12.2\n"
"    Виправлено підвисання інтерфейсу під час передачі файлів.\n"
"    Виправлено падіння під час передачі файлів на Windows.\n"
"\nv0.11.1\n"
"    Виправлено падіння під час деяких передач.\n"
"    Виправлення багів\n"
"    Виправлено збирання на Windows XP\n"
"    Покращено запит на додання до друзів\n"
"    Додано можливість змінювати антиспам-код\n"
"    Додано вкладки налаштувань \"Сповіщення\" та \"Додатково\"\n"
"    Новий оновлювач\n"
"    Розпочато відокремлення ядра від інтерфейсу.\n"
"\nv0.11.1\n"
"    Функція: Експорт історії чату\n"
"    Функція: Додано можливість відхиляти дзвінки\n"
"    Різні виправлення безпеки\n"
"    Виправлено проблему зі значком\n"
"    Краща система збирання\n"
"    Перехід до TokTok/c-toxcore\n"
"    Покращено процес розробки для спрощення додавання коду\n"
"    Нові теми: Solarized світла та Solarized темна\n"
"    Оновлено переклади\n"
"    оптимізація filter_audio\n"
"    Розпочато використання clang-format\n"
"    Припинено використання clang-format\n"
"    Нові, гарніші кнопки (подяка tsudoko!)\n"
"    Краща підтримка автоматичного прийняття передач файлів\n"
"    Виправлено проблеми інтерфейсу через заблокований екран\n"
"\nv0.11.0\n"
"    Перепрошуємо, але історія змін для цієї версії uTox\n"
"    доступна лише для власників Золотої Картки uTox.\n"
"\nv0.9.8\n"
"    Виправлено падіння під час створення нового профілю\n"
"\nv0.9.7\n"
"    Невеличкі виправлення інтерфейсу\n"
"    Замінено усі випадні списки \"Так/Ні\" на перемикачі\n"
"    Виправлено збереження проксі та порту після перезапуску.\n"
"\nv0.9.5\n"
"    Вбудоване відео на OSX\n"
"    Виправлено помилку журналювання\n"
"\nv0.9.3\n"
"    Виправлено помилку в повідомленні, яка подекуди руйнувала uTox на Windows\n"
"    Обмежено кількість повідомлень для одночасного надсилання\n"
"\nv0.9.2\n"
"    Чищення вихідних текстів/зміни дерева каталогів\n"
"\nv0.9.1\n"
"    Виправлено падіння під час надсилання повідомлення новому другові\n"
"\nv0.9.0\n"
"   Черга повідомлень\n"
"   Кращий, кольоровий груповий чат\n"
"   Експериментальна підтримка вбудованого відео\n"
"   Компактний список друзів\n"
"   Перебудова обробки повідомлень\n"
"\n")

/******************************************************************************
 *** MISC & UNSORTED                                                        ***
 ******************************************************************************/

msgid(REQ_SENT)
msgstr("Запит на додавання в друзі відправлений. Ваш друг з'явиться в мережі, як тільки підтвердить запит.")

msgid(REQ_INVALID_ID)
msgstr("Помилка: Невірний Tox ID")

msgid(REQ_ADDED_NO_FREQ_SENT)
msgstr("Увага: Друга додано, але запит не надіслано (відсутній антиспам)")

msgid(REQ_EMPTY_ID)
msgstr("Помилка: Не вказано Tox ID")

msgid(REQ_LONG_MSG)
msgstr("Помилка: Повідомлення занадто довге")

msgid(REQ_NO_MSG)
msgstr("Помилка: Порожнє повідомлення")

msgid(REQ_SELF_ID)
msgstr("Помилка: Tox ID є власним ID")

msgid(REQ_ALREADY_FRIENDS)
msgstr("Помилка: Tox ID вже є у списку друзів")

msgid(REQ_UNKNOWN)
msgstr("Помилка: Невідома")

msgid(REQ_BAD_CHECKSUM)
msgstr("Помилка: Невірний Tox ID (контрольна сума не збігається)")

msgid(REQ_BAD_NOSPAM)
msgstr("Помилка: Невірний Tox ID (невірний антиспам-код)")

msgid(REQ_NO_MEMORY)
msgstr("Помилка: Недостатньо пам'яті")

msgid(SEND_FILE)
msgstr("Надіслати файл")

msgid(SAVE_FILE)
msgstr("Збереження файлу")

msgid(WHERE_TO_SAVE_FILE_PROMPT)
msgstr("Оберіть місце для збереження\"%.*s\"")

msgid(WHERE_TO_SAVE_FILE)
msgstr("Куди ви хочете зберегти файл?")

msgid(SEND_FILE_PROMPT)
msgstr("Оберіть файл(и) для надсилання.")

msgid(SCREEN_CAPTURE_PROMPT)
msgstr("Позначте область екрана для надсилання.")


/******************************************************************************
 *** File Transfer Strings                                                  ***
 ******************************************************************************/
msgid(TRANSFER_NEW)
msgstr("Передача файлу")

msgid(TRANSFER_STARTED)
msgstr("Розпочато передачу файлу")

msgid(TRANSFER___)
msgstr("...")

msgid(TRANSFER_PAUSED)
msgstr("Призупинено передачу файлу")

msgid(TRANSFER_BROKEN)
msgstr("Перервано передачу файлу")

msgid(TRANSFER_CANCELLED)
msgstr("Скасовано передачу файлу")

msgid(TRANSFER_COMPLETE)
msgstr("Завершено передачу файлу")


/******************************************************************************
 *** Keyboard and Mouse Cursor Strings                                      ***
 ******************************************************************************/
msgid(CURSOR_CLICK_LEFT)
msgstr("Ліва кнопка")

msgid(CURSOR_CLICK_RIGHT)
msgstr("Права кнопка")


/******************************************************************************
 *** Audio / Video Call Strings                                             ***
 ******************************************************************************/
msgid(CALL_START_AUDIO)
msgstr("Зателефонувати")

msgid(CALL_START_VIDEO)
msgstr("Здійснити відеодзвінок")

msgid(CALL_DECLINE)
msgstr("Відхилити дзвінок")

msgid(CALL_CANCELLED)
msgstr("Дзвінок відхилено")

msgid(CALL_INVITED)
msgstr("Вхідний дзвінок")

msgid(CALL_RINGING)
msgstr("Вихідний дзвінок")

msgid(CALL_STARTED)
msgstr("Розпочато розмову")

msgid(CALL_ENDED)
msgstr("Розмову закінчено")

msgid(CALL_FRIEND_HAD_ENDED_CALL)
msgstr(" закінчив розмову.")

msgid(CALL_VIDEO_SHOW_INLINE)
msgstr("Вбудувати відео")


/******************************************************************************
 *** Friend & Friend Settings Strings                                       ***
 ******************************************************************************/
msgid(FRIEND_ALIAS)
msgstr("Псевдонім друга")

msgid(FRIEND_PUBLIC_KEY)
msgstr("Відкритий ключ друга")

msgid(FRIEND_AUTOACCEPT)
msgstr("Приймати вхідні файли без підтвердження")

msgid(FRIEND_EXPORT_CHATLOG)
msgstr("Зберегти історію чату як текст")


/******************************************************************************
 *** Group Strings                                                          ***
 ******************************************************************************/
msgid(GROUPCHAT_JOIN_AUDIO)
msgstr("Приєднатися до аудіо чату")

msgid(GROUP_CREATE_TEXT)
msgstr("Створити текстовий чат")

msgid(GROUP_CREATE_VOICE)
msgstr("Створити голосовий чат")

msgid(CREATEGROUPCHAT)
msgstr("Створити чат")

msgid(REMOVE_GROUP)
msgstr("Видалити чат")

msgid(LEAVE_GROUP)
msgstr("Вийти з чату")


/******************************************************************************
 *** Group Settings                                                         ***
 ******************************************************************************/
msgid(GROUPCHAT_SETTINGS)
msgstr("Налаштування чату")

msgid(GROUP_NOTIFICATIONS)
msgstr("Повідомлення чату")

msgid(GROUP_NOTIFICATIONS_ON)
msgstr("Усі")

msgid(GROUP_NOTIFICATIONS_MENTION)
msgstr("Звернення")

msgid(GROUP_NOTIFICATIONS_OFF)
msgstr("Немає")

msgid(GROUP_TOPIC)
msgstr("Встановити тему")

/******************************************************************************
 *** Settings / Profile Strings                                             ***
 ******************************************************************************/
msgid(PROFILE_BUTTON)
msgstr("Профіль")

msgid(DEVICES_BUTTON)
msgstr("Пристрої")

msgid(USER_INTERFACE_BUTTON)
msgstr("Інтерфейс")

msgid(AUDIO_VIDEO_BUTTON)
msgstr("Аудіо/Відео")

msgid(ADVANCED_BUTTON)
msgstr("Додатково")

msgid(NOTIFICATIONS_BUTTON)
msgstr("Сповіщення")

msgid(PROFILE_SETTINGS)
msgstr("Налаштування профілю")

msgid(PROFILE_PW_WARNING)
msgstr("ПОПЕРЕДЖЕННЯ: µTox автоматично почне шифрування за допомогою цього пароля.")

msgid(PROFILE_PW_NO_RECOVER)
msgstr("Відновлення забутих паролів неможливо!")



/***     	Profile                                                         ***/

/***     	Devices                                                         ***/
msgid(DEVICES_ADD_NEW)
msgstr("Додати новий пристрій до мережі")

msgid(DEVICES_NUMBER)
msgstr("Кількість пов'язаних пристроїв")
/*** 		Network                                                         ***/

/***    	User Interface                                                  ***/

/***		Audio/Video                                                     ***/



/******************************************************************************
 *** UNSORTED STRINGS                                                       ***
 *** TODO:                                                                  ***
 *** FIXME:                                                                 ***
 ******************************************************************************/
msgid(ADDFRIENDS)
msgstr("Додати друзів")

msgid(TOXID)
msgstr("Tox ID")

msgid(MESSAGE)
msgstr("Повідомлення")

msgid(FILTER_ONLINE)
msgstr("Онлайн")

msgid(FILTER_ALL)
msgstr("Всі")

msgid(FILTER_CONTACT_TOGGLE)
msgstr("Перемикання фільтрації оффлайн контактів.")

msgid(ADD)
msgstr("Додати")

msgid(FRIENDREQUEST)
msgstr("Запит на додавання до списку друзів")

msgid(USERSETTINGS)
msgstr("Налаштування")

msgid(FRIEND_SETTINGS)
msgstr("Налаштування друзів")

msgid(NAME)
msgstr("Ім'я")

msgid(STATUSMESSAGE)
msgstr("Статус")

msgid(PREVIEW)
msgstr("Перевірка")

msgid(AUDIOINPUTDEVICE)
msgstr("Пристрій захоплення звуку")

msgid(AUDIOFILTERING)
msgstr("Фільтр аудіо") // Check the correctness

msgid(AUDIOOUTPUTDEVICE)
msgstr("Пристрій відтворення звуку")

msgid(VIDEOINPUTDEVICE)
msgstr("Пристрій захоплення відео")

msgid(VIDEOFRAMERATE)
msgstr("Частота кадрів відео (FPS)")

msgid(PUSH_TO_TALK)
msgstr("Натисніть щоб говорити")

msgid(STATUS)
msgstr("Статус")

msgid(STATUS_ONLINE)
msgstr("Онлайн")

msgid(STATUS_AWAY)
msgstr("Далеко")

msgid(STATUS_BUSY)
msgstr("Зайнятий")

msgid(STATUS_OFFLINE)
msgstr("Поза мережею")

/*
 * Leave %.*s. They are variables
 * The first one is your friend's name
 * The second one is the state your friend is now in
 */
msgid(STATUS_MESSAGE)
msgstr("uTox %.*s тепер %s.")

msgid(SETTINGS_UI_MINI_ROSTER)
msgstr("Компактний список друзів")

msgid(SETTINGS_UI_AUTO_HIDE_SIDEBAR)
msgstr("Ховати бічну панель")

msgid(NOT_CONNECTED)
msgstr("Роз'єднано")

msgid(NOT_CONNECTED_SETTINGS)
msgstr("Налаштування мережі") // чи "Перевірте налаштування мережі"?

msgid(OTHERSETTINGS)
msgstr("Інші налаштування")

msgid(UI)
msgstr("Інтерфейс")

msgid(USER_INTERFACE)
msgstr("Інтерфейс")

msgid(UTOX_SETTINGS)
msgstr("Налаштування uTox")

msgid(NETWORK_SETTINGS)
msgstr("Налаштування мережі")

msgid(PROFILE_PASSWORD)
msgstr("Пароль профілю")

msgid(LOCK_UTOX)
msgstr("Від'єднатися від мережі Tox і заблокувати даний профіль")

msgid(SHOW_UI_PASSWORD)
msgstr("Показати поле пароля")

msgid(SHOW_UI_PASSWORD_TOOLTIP)
msgstr("Натисніть щоб побачити поле для введення пароля. Зміни буде застосовано миттєво!")

msgid(HIDE_UI_PASSWORD)
msgstr("Сховати поле пароля")

msgid(HIDE_UI_PASSWORD_TOOLTIP)
msgstr("Клацніть, щоб приховати поле введення пароля від вашого профілю.")

msgid(PASSWORD_TOO_SHORT)
msgstr("Пароль повинен містити не менше 4 символів")

msgid(LOCK)
msgstr("Заблокувати")

msgid(AUDIO_VIDEO)
msgstr("Аудіо/Відео")

msgid(DPI)
msgstr("Масштаб")

msgid(SAVELOCATION)
msgstr("Місце збереження")

msgid(LANGUAGE)
msgstr("Мова")

msgid(NETWORK)
msgstr("Мережа")

msgid(IPV6)
msgstr("IPv6:")

msgid(UDP)
msgstr("UDP:")

msgid(PROXY)
msgstr("Проксі (SOCKS 5)")

msgid(PROXY_FORCE)
msgstr("Завжти використовувати проксі")

msgid(WARNING)
msgstr("Зміна налаштувань мережі або проксі-сервера потребує від'єднання від мережі Tox")

msgid(SAVE_CHAT_HISTORY)
msgstr("Зберігати історію чату")

msgid(AUDIONOTIFICATIONS)
msgstr("Ввімкнути звукове сповіщення (рингтон)")

msgid(RINGTONE)
msgstr("Сигнал") // Мелодія?

msgid(IS_TYPING)
msgstr("набирає повідомлення...")

msgid(CLOSE_TO_TRAY)
msgstr("Сховати в лоток") // Check the correctness (трей чи  системний лоток)

msgid(START_IN_TRAY)
msgstr("Запускати в лотку") // Check the correctness (трей чи  системний лоток)

msgid(SHOW_QR)
msgstr("Показати QR")

msgid(HIDE_QR)
msgstr("Сховати QR")

msgid(SAVE_QR)
msgstr("Зберегти QR")

msgid(COPY_TOX_ID)
msgstr("Скопіювати як текст")

msgid(COPY)
msgstr("Копіювати")

msgid(COPYWITHOUTNAMES)
msgstr("Копіювати (без імені)")

msgid(COPY_WITH_NAMES)
msgstr("Копіювати (з іменем)")

msgid(CUT)
msgstr("Вирізати")

msgid(PASTE)
msgstr("Вставити")

msgid(DELETE)
msgstr("Видалити")

msgid(SELECTALL)
msgstr("Вибрати все")

msgid(REMOVE)
msgstr("Видалити")

msgid(REMOVE_FRIEND)
msgstr("Видалити друга")

msgid(LEAVE)
msgstr("Вийти")

msgid(CTOPIC)
msgstr("Змінити тему")

msgid(ACCEPT)
msgstr("Прийняти")

msgid(IGNORE)
msgstr("Ігнорувати")

msgid(SET_ALIAS)
msgstr("Встановити псевдонім")

msgid(ALIAS)
msgstr("Псевдонім")

msgid(SENDMESSAGE)
msgstr("Надіслати повідомлення")

msgid(SENDSCREENSHOT)
msgstr("Надіслати знімок екрану")

msgid(CLICKTOSAVE)
msgstr("Натисніть для збереження")

msgid(CLICKTOOPEN)
msgstr("Натисніть для відкриття")

msgid(CANCELLED)
msgstr("Скасовано")

msgid(DPI_060)
msgstr("Масштаб 60%")

msgid(DPI_070)
msgstr("Масштаб 70%")

msgid(DPI_080)
msgstr("Масштаб 80%")

msgid(DPI_090)
msgstr("Масштаб 90%")

msgid(DPI_100)
msgstr("Масштаб 100%")

msgid(DPI_110)
msgstr("Масштаб 110%")

msgid(DPI_120)
msgstr("Масштаб 120%")

msgid(DPI_130)
msgstr("Масштаб 130%")

msgid(DPI_140)
msgstr("Масштаб 140%")

msgid(DPI_150)
msgstr("Масштаб 150%")

msgid(DPI_160)
msgstr("Масштаб 160%")

msgid(DPI_170)
msgstr("Масштаб 170%")

msgid(DPI_180)
msgstr("Масштаб 180%")

msgid(DPI_190)
msgstr("Масштаб 190%")

msgid(DPI_200)
msgstr("Масштаб 200%")

msgid(DPI_210)
msgstr("Масштаб 210%")

msgid(DPI_220)
msgstr("Масштаб 220%")

msgid(DPI_230)
msgstr("Масштаб 230%")

msgid(DPI_240)
msgstr("Масштаб 240%")

msgid(DPI_250)
msgstr("Масштаб 250%")

msgid(DPI_260)
msgstr("Масштаб 260%")

msgid(DPI_270)
msgstr("Масштаб 270%")

msgid(DPI_280)
msgstr("Масштаб 280%")

msgid(DPI_290)
msgstr("Масштаб 290%")

msgid(DPI_300)
msgstr("Масштаб 300%")

msgid(DPI_TINY)
msgstr("Дрібний (50%)")

msgid(DPI_NORMAL)
msgstr("Нормальний (100%)")

msgid(DPI_BIG)
msgstr("Крупний (150%)")

msgid(DPI_LARGE)
msgstr("Великий (200%)")

msgid(DPI_HUGE)
msgstr("Дуже великий (250%)")

msgid(PROXY_DISABLED)
msgstr("Вимкнено")

msgid(PROXY_FALLBACK)
msgstr("За потреби")

msgid(PROXY_ALWAYS_USE)
msgstr("Завжди")

msgid(NO)
msgstr("Ні")

msgid(YES)
msgstr("Так")

msgid(OFF)
msgstr("Ні") // Вимк.?

msgid(ON)
msgstr("Так") // Увімк.?

msgid(SHOW)
msgstr("Показати")

msgid(HIDE)
msgstr("Приховати")

msgid(VIDEO_IN_NONE)
msgstr("Не вибрано")

msgid(VIDEO_IN_DESKTOP)
msgstr("Стільниця")

msgid(AUDIO_IN_DEFAULT_LOOPBACK)
msgstr("Стандартна петля") // Check the correctness

msgid(AUDIO_IN_ANDROID)
msgstr("Ввід OpenSL")

msgid(DEFAULT_FRIEND_REQUEST_MESSAGE)
msgstr("Будь ласка, додайте мене в свій список друзів.")

msgid(CONTACT_SEARCH_ADD_HINT)
msgstr("Пошук/Додавання Друзів")

msgid(PROXY_EDIT_HINT_IP)
msgstr("IP")

msgid(PROXY_EDIT_HINT_PORT)
msgstr("Порт")

msgid(WINDOW_TITLE_VIDEO_PREVIEW)
msgstr("Попередній перегляд відео")

msgid(MUTE)
msgstr("Заглушити")

msgid(UNMUTE)
msgstr("Відновити")

msgid(SELECT_AVATAR_TITLE)
msgstr("Оберіть аватар")

msgid(AVATAR_TOO_LARGE_MAX_SIZE_IS)
msgstr("Аватар занадто великий. Максимальний розмір: ")

msgid(CANT_FIND_FILE_OR_EMPTY)
msgstr("Вказаний файл не існує або порожній.")

msgid(CLEAR_HISTORY)
msgstr("Очистити історію")

msgid(AUTO_STARTUP)
msgstr("Запускати під час завантаження системи")

msgid(THEME)
msgstr("Тема")

msgid(THEME_DEFAULT)
msgstr("Базова")

msgid(THEME_LIGHT)
msgstr("Світла")

msgid(THEME_DARK)
msgstr("Темна")

msgid(THEME_HIGHCONTRAST)
msgstr("Контрастна")

msgid(THEME_CUSTOM)
msgstr("Власна (див. документацію)")

msgid(THEME_ZENBURN)
msgstr("Zenburn")

msgid(THEME_SOLARIZED_LIGHT)
msgstr("Solarized світла")

msgid(THEME_SOLARIZED_DARK)
msgstr("Solarized темна")

msgid(SEND_TYPING_NOTIFICATIONS)
msgstr("Повідомляти про набір відповіді")

msgid(STATUS_NOTIFICATIONS)
msgstr("Зміна статусу")

msgid(RANDOMIZE_NOSPAM)
msgstr("Згенерувати антиспам-код")

msgid(NOSPAM)
msgstr("Антиспам-код")

msgid(REVERT_NOSPAM)
msgstr("Відновити антиспам-код")

msgid(NOSPAM_WARNING)
msgstr("Зміна антиспам-коду зробить недійсним ваш старий Tox ID. uTox не оновлює ваш ID на серверах імен.")

msgid(BLOCK_FRIEND_REQUESTS)
msgstr("Заборонити запити на додання друзів")

msgid(SHOW_NOSPAM)
msgstr("Показати антиспам-код")

msgid(HIDE_NOSPAM)
msgstr("Сховати налаштування антиспам-коду")

msgid(DELETE_FRIEND)
msgstr("Видалити з друзів")

msgid(DELETE_MESSAGE)
msgstr("Дійсно видалити ")

msgid(KEEP)
msgstr("Залишити")
